Data documentation compiled by Great Expectations

### Overview

#### Dataset info

Number of variables | 2
Number of observations expect_table_row_count_to_be_between | 3
Missing cells | 50.00%

#### Variable types

int | 1
float | 1
string | 0
-- | 0

#### Expectation types

- expect_column_values_to_be_in_type_list 2
- expect_column_unique_value_count_to_be_between 2
- expect_column_proportion_of_unique_values_to_be_between 2
- expect_column_values_to_not_be_null 2
- expect_column_values_to_be_in_set 2
- expect_table_row_count_to_be_between 1
- expect_table_columns_to_match_ordered_list 1
- expect_column_values_to_be_unique 1

### Unnamed: 0 expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 3
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 100.0%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 2 3

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_values_to_be_unique True

### Unnamed: 1 expect_column_to_exist

##### Type: float expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 0
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | --
Missing (n) expect_column_values_to_not_be_null | 3
Missing (%) expect_column_values_to_not_be_null | 100.0%

#### Example Values expect_column_values_to_be_in_set

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null False
- expect_column_values_to_be_in_set True

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.